@@ -4,6 +4,16 @@ exports.main = function() {
         return;
     }
 
+    // Automatically refresh when the AppCache is changed
+    if (window.applicationCache) {
+        applicationCache.addEventListener("updateready",
+            function(e) {
+                if (applicationCache.status == applicationCache.UPDATEREADY) {
+                    document.location.reload();
+                }
+            }, false);
+    }
+
     var touchpad, touchview;
     var touchviewEl = document.getElementById("touchpad");
 
