@@ -95,17 +95,7 @@ exports.view = (function() {
         var xdirection = -1;
         var ydirection = -1;
 
-        return [
-            dx > 0
-                ? xdirection
-                : dx < 0
-                    ? -xdirection
-                    : 0,
-            dy > 0
-                ? ydirection
-                : dy < 0
-                    ? -ydirection
-                    : 0];
+        return [dx * xdirection, dy * ydirection];
     }
 
     /**
